markupsafe: Safely add untrusted strings to HTML/XML markup
===========================================================

Description
-----------

Implements a XML/HTML/XHTML Markup safe string for Python

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/MarkupSafe/

